@@ -90,6 +90,7 @@ fs2ulong_done:
 */
 
 /* (c)2000/2001: hacked a little by johan.knol@iduna.nl for sdcc */
+/* (c)2022:      fix sdcc bug #3276 -- Benedikt Freisen */
 
 
 union float_long
@@ -103,18 +104,24 @@ unsigned long
 __fs2ulong (float a1)
 {
   volatile union float_long fl1;
-  volatile int exp;
-  volatile long l;
-  
+  int exp;
+  unsigned long l;
+
   fl1.f = a1;
-  
+
   if (!fl1.l || SIGN(fl1.l))
     return (0);
 
   exp = EXP (fl1.l) - EXCESS - 24;
   l = MANT (fl1.l);
-  
-  l >>= -exp;
+
+  if (exp > 8)
+    return 0xfffffffful;
+
+  if (exp < 0)
+    l >>= -exp;
+  else
+    l <<= exp;
 
   return l;
 }
