@@ -1,26 +1,29 @@
 /*-------------------------------------------------------------------------
+   _gptrget.c - get value for a generic pointer
 
-  _gptrget.c :- get value for a generic pointer
-
-             Written By -  Sandeep Dutta . sandeep.dutta@usa.net (1999)
+   Copyright (c) 1999, Sandeep Dutta . sandeep.dutta@usa.net
 
    This library is free software; you can redistribute it and/or modify it
-   under the terms of the GNU Library General Public License as published by the
+   under the terms of the GNU General Public License as published by the
    Free Software Foundation; either version 2, or (at your option) any
    later version.
 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU Library General Public License for more details.
+   GNU General Public License for more details.
 
-   You should have received a copy of the GNU Library General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   You should have received a copy of the GNU General Public License
+   along with this library; see the file COPYING. If not, write to the
+   Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,
+   MA 02110-1301, USA.
 
-   In other words, you are welcome to use, share and improve this program.
-   You are forbidden to forbid anyone else to use, share and improve
-   what you give them.   Help stamp out software-hoarding!
+   As a special exception, if you link this library with other files,
+   some of which are compiled with SDCC, to produce an executable,
+   this library does not by itself cause the resulting executable to
+   be covered by the GNU General Public License. This exception does
+   not however invalidate any other reasons why the executable file
+   might be covered by the GNU General Public License.
 -------------------------------------------------------------------------*/
 
 /* not all devices use P2 to page pdata memory, therefore __XPAGE was
@@ -213,8 +216,8 @@ _gptrget (char *gptr) __naked
 
 #endif
 
-#ifdef SDCC_ds390
-/* the  return value is expected to be in acc/_ap, and not in the standard
+#ifdef __SDCC_ds390
+/* the  return value is expected to be in acc/acc1, and not in the standard
  * location dpl/dph. Therefore we choose return type void here: */
 
 void
@@ -236,7 +239,7 @@ _gptrgetWord (unsigned *gptr)
     ;
     ;   Pointer to data space
     ;
-        mov     _ap,@r0
+        mov     acc1,@r0
         inc     r0
         mov     a,@r0
         inc     dpl
@@ -246,7 +249,7 @@ _gptrgetWord (unsigned *gptr)
     ;
  00002$:
         movx    a,@dptr
-        mov     _ap,a
+        mov     acc1,a
         inc     dptr
         movx    a,@dptr
         sjmp    00006$
@@ -256,7 +259,7 @@ _gptrgetWord (unsigned *gptr)
  00003$:
         clr     a
         movc    a,@a+dptr
-        mov     _ap,a
+        mov     acc1,a
         clr     a
         inc     dptr
         movc    a,@a+dptr
@@ -266,7 +269,7 @@ _gptrgetWord (unsigned *gptr)
 ;
  00004$:
         movx    a,@r0
-        mov     _ap,a
+        mov     acc1,a
         inc     r0
         movx    a,@r0
         inc     dpl
@@ -277,7 +280,7 @@ _gptrgetWord (unsigned *gptr)
         mov     r0,dph ; restore r0
         mov     dph,#0 ; restore dph
  00006$:
-        xch     a,_ap
+        xch     a,acc1
     __endasm;
 
 }
