@@ -1,27 +1,30 @@
 /*-------------------------------------------------------------------------
-  _moduint.c :- routine for unsigned int (16 bit) modulus
+   _moduint.c - routine for unsigned int (16 bit) modulus
 
-             Written By -  Sandeep Dutta . sandeep.dutta@usa.net (1999)
-
-             Bug fixes by Martijn van Balen, aed@iae.nl
+   Copyright (C) 1999, Sandeep Dutta . sandeep.dutta@usa.net
+   Bug fixes by Martijn van Balen, aed@iae.nl
 
    This library is free software; you can redistribute it and/or modify it
-   under the terms of the GNU Library General Public License as published by the
+   under the terms of the GNU General Public License as published by the
    Free Software Foundation; either version 2, or (at your option) any
    later version.
 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU Library General Public License for more details.
+   GNU General Public License for more details.
 
-   You should have received a copy of the GNU Library General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   You should have received a copy of the GNU General Public License
+   along with this library; see the file COPYING. If not, write to the
+   Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,
+   MA 02110-1301, USA.
 
-   In other words, you are welcome to use, share and improve this program.
-   You are forbidden to forbid anyone else to use, share and improve
-   what you give them.   Help stamp out software-hoarding!
+   As a special exception, if you link this library with other files,
+   some of which are compiled with SDCC, to produce an executable,
+   this library does not by itself cause the resulting executable to
+   be covered by the GNU General Public License. This exception does
+   not however invalidate any other reasons why the executable file
+   might be covered by the GNU General Public License.
 -------------------------------------------------------------------------*/
 
 /*   Assembler-functions are provided for:
@@ -29,10 +32,10 @@
      mcs51 small stack-auto
 */
 
-#if !defined(SDCC_USE_XSTACK) && !defined(_SDCC_NO_ASM_LIB_FUNCS)
-#  if defined(SDCC_mcs51)
-#    if defined(SDCC_MODEL_SMALL)
-#      if defined(SDCC_STACK_AUTO)
+#if !defined(__SDCC_USE_XSTACK) && !defined(_SDCC_NO_ASM_LIB_FUNCS)
+#  if defined(__SDCC_mcs51)
+#    if defined(__SDCC_MODEL_SMALL)
+#      if defined(__SDCC_STACK_AUTO)
 #        define _MODUINT_ASM_SMALL_AUTO
 #      else
 #        define _MODUINT_ASM_SMALL
@@ -56,7 +59,7 @@ __moduint:
 	#define al      dpl
 	#define ah      dph
 
-#if defined(SDCC_STACK_AUTO) && !defined(SDCC_PARMS_IN_BANK1)
+#if defined(__SDCC_STACK_AUTO) && !defined(__SDCC_PARMS_IN_BANK1)
 
 	ar0 = 0			; BUG register set is not considered
 	ar1 = 1
@@ -76,10 +79,10 @@ __moduint:
 __modint:			; entry point for __modsint
 
 
-#else // SDCC_STACK_AUTO
+#else // __SDCC_STACK_AUTO
 
-#if !defined(SDCC_PARMS_IN_BANK1)
-#if defined(SDCC_NOOVERLAY)
+#if !defined(__SDCC_PARMS_IN_BANK1)
+#if defined(__SDCC_NOOVERLAY)
 	.area DSEG    (DATA)
 #else
 	.area OSEG    (OVR,DATA)
@@ -100,7 +103,7 @@ __modsint_PARM_2:
 	#define bl      (b1_0)
 	#define bh      (b1_1)
 #endif
-#endif // SDCC_STACK_AUTO
+#endif // __SDCC_STACK_AUTO
 
 	mov	a,bl		; avoid endless loop
 	orl	a,bh
@@ -164,14 +167,13 @@ div_by_0:
 
 #else  // defined _MODUINT_ASM_SMALL || defined _MODUINT_ASM_SMALL_AUTO
 
-#define MSB_SET(x) ((x >> (8*sizeof(x)-1)) & 1) 
+#define MSB_SET(x) ((x >> (8*sizeof(x)-1)) & 1)
 
 unsigned int
 _moduint (unsigned int a, unsigned int b)
 {
   unsigned char count = 0;
-    
-    
+
   while (!MSB_SET(b))
   {
     b <<= 1;
